@@ -34,6 +34,8 @@ from modin.core.storage_formats.pandas.utils import compute_chunksize
 from modin.utils import _inherit_docstrings
 from modin.core.io.text.utils import CustomNewlineIterator
 from modin.config import NPartitions
+from modin.error_message import ErrorMessage
+from modin.logging import logger_decorator
 
 ColumnNamesTypes = Tuple[Union[pandas.Index, pandas.MultiIndex]]
 IndexColType = Union[int, str, bool, Sequence[int], Sequence[str], None]
@@ -47,6 +49,7 @@ class TextFileDispatcher(FileDispatcher):
     read_callback = None
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.get_path_or_buffer", "INFO")
     def get_path_or_buffer(cls, filepath_or_buffer):
         """
         Extract path from `filepath_or_buffer`.
@@ -72,13 +75,14 @@ class TextFileDispatcher(FileDispatcher):
             if cls.file_exists(buffer_filepath):
                 warnings.warn(
                     "For performance reasons, the filepath will be "
-                    "used in place of the file handle passed in "
-                    "to load the data"
+                    + "used in place of the file handle passed in "
+                    + "to load the data"
                 )
                 return cls.get_path(buffer_filepath)
         return filepath_or_buffer
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.build_partition", "INFO")
     def build_partition(cls, partition_ids, row_lengths, column_widths):
         """
         Build array with partitions of `cls.frame_partition_cls` class.
@@ -113,6 +117,7 @@ class TextFileDispatcher(FileDispatcher):
         )
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.pathlib_or_pypath", "INFO")
     def pathlib_or_pypath(cls, filepath_or_buffer):
         """
         Check if `filepath_or_buffer` is instance of `py.path.local` or `pathlib.Path`.
@@ -145,6 +150,7 @@ class TextFileDispatcher(FileDispatcher):
         return False
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.offset", "INFO")
     def offset(
         cls,
         f,
@@ -202,6 +208,7 @@ class TextFileDispatcher(FileDispatcher):
         return outside_quotes
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.partitioned_file", "INFO")
     def partitioned_file(
         cls,
         f,
@@ -330,6 +337,7 @@ class TextFileDispatcher(FileDispatcher):
         return result
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._read_rows", "INFO")
     def _read_rows(
         cls,
         f,
@@ -401,6 +409,7 @@ class TextFileDispatcher(FileDispatcher):
         return outside_quotes, rows_read
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.compute_newline", "INFO")
     def compute_newline(cls, file_like, encoding, quotechar):
         """
         Compute byte or sequence of bytes indicating line endings.
@@ -456,6 +465,7 @@ class TextFileDispatcher(FileDispatcher):
 
     # _read helper functions
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher.rows_skipper_builder", "INFO")
     def rows_skipper_builder(
         cls, f, quotechar, is_quoting, encoding=None, newline=None
     ):
@@ -497,6 +507,7 @@ class TextFileDispatcher(FileDispatcher):
         return skipper
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._define_header_size", "INFO")
     def _define_header_size(
         cls,
         header: Union[int, Sequence[int], str, None] = "infer",
@@ -528,6 +539,7 @@ class TextFileDispatcher(FileDispatcher):
         return header_size
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._define_metadata", "INFO")
     def _define_metadata(
         cls,
         df: pandas.DataFrame,
@@ -575,6 +587,7 @@ class TextFileDispatcher(FileDispatcher):
         return column_widths, num_splits
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._launch_tasks", "INFO")
     def _launch_tasks(cls, splits: list, **partition_kwargs) -> Tuple[list, list, list]:
         """
         Launch tasks to read partitions.
@@ -596,25 +609,28 @@ class TextFileDispatcher(FileDispatcher):
         dtypes_ids : list
             array with references to the partitions dtypes objects.
         """
-        partition_ids = []
-        index_ids = []
-        dtypes_ids = []
-        for start, end in splits:
+        partition_ids = [None] * len(splits)
+        index_ids = [None] * len(splits)
+        dtypes_ids = [None] * len(splits)
+        for idx, (start, end) in enumerate(splits):
             partition_kwargs.update({"start": start, "end": end})
-            partition_id = cls.deploy(
-                cls.parse, partition_kwargs.get("num_splits") + 2, partition_kwargs
+            *partition_ids[idx], index_ids[idx], dtypes_ids[idx] = cls.deploy(
+                cls.parse,
+                num_returns=partition_kwargs.get("num_splits") + 2,
+                **partition_kwargs,
             )
-            partition_ids.append(partition_id[:-2])
-            index_ids.append(partition_id[-2])
-            dtypes_ids.append(partition_id[-1])
-
         return partition_ids, index_ids, dtypes_ids
 
     @classmethod
+    @logger_decorator(
+        "PANDAS-API", "TextFileDispatcher.check_parameters_support", "INFO"
+    )
     def check_parameters_support(
         cls,
         filepath_or_buffer,
         read_kwargs: dict,
+        skiprows_md: Union[Sequence, callable, int],
+        header_size: int,
     ) -> bool:
         """
         Check support of only general parameters of `read_*` function.
@@ -625,12 +641,17 @@ class TextFileDispatcher(FileDispatcher):
             `filepath_or_buffer` parameter of `read_*` function.
         read_kwargs : dict
             Parameters of `read_*` function.
+        skiprows_md : int, array or callable
+            `skiprows` parameter modified for easier handling by Modin.
+        header_size : int
+            Number of rows that are used by header.
 
         Returns
         -------
         bool
             Whether passed parameters are supported or not.
         """
+        skiprows = read_kwargs.get("skiprows")
         if isinstance(filepath_or_buffer, str):
             if not cls.file_exists(filepath_or_buffer):
                 return False
@@ -640,14 +661,33 @@ class TextFileDispatcher(FileDispatcher):
         if read_kwargs["chunksize"] is not None:
             return False
 
+        skiprows_supported = True
+        if is_list_like(skiprows_md) and skiprows_md[0] < header_size:
+            skiprows_supported = False
+        elif callable(skiprows):
+            # check if `skiprows` callable gives True for any of header indices
+            is_intersection = any(
+                cls._get_skip_mask(pandas.RangeIndex(header_size), skiprows)
+            )
+            if is_intersection:
+                skiprows_supported = False
+
+        if not skiprows_supported:
+            ErrorMessage.single_warning(
+                "Values of `header` and `skiprows` parameters have intersections. "
+                + "This case is unsupported by Modin, so pandas implementation will be used"
+            )
+            return False
+
         return True
 
     @classmethod
     @_inherit_docstrings(pandas.io.parsers.base_parser.ParserBase._validate_usecols_arg)
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._validate_usecols_arg", "INFO")
     def _validate_usecols_arg(cls, usecols):
         msg = (
             "'usecols' must either be list-like of all strings, all unicode, "
-            "all integers or a callable."
+            + "all integers or a callable."
         )
         if usecols is not None:
             if callable(usecols):
@@ -667,6 +707,9 @@ class TextFileDispatcher(FileDispatcher):
         return usecols, None
 
     @classmethod
+    @logger_decorator(
+        "PANDAS-API", "TextFileDispatcher._manage_skiprows_parameter", "INFO"
+    )
     def _manage_skiprows_parameter(
         cls,
         skiprows: Union[int, Sequence[int], Callable, None] = None,
@@ -758,7 +801,7 @@ class TextFileDispatcher(FileDispatcher):
                 )
                 skiprows_partitioning = len(skiprows_md)
                 skiprows_md = 0
-            else:
+            elif skiprows_md[0] > header_size:
                 skiprows_md = skiprows_md - header_size
         elif callable(skiprows):
 
@@ -770,6 +813,7 @@ class TextFileDispatcher(FileDispatcher):
         return skiprows_md, pre_reading, skiprows_partitioning
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._define_index", "INFO")
     def _define_index(
         cls,
         index_ids: list,
@@ -805,6 +849,7 @@ class TextFileDispatcher(FileDispatcher):
         return new_index, row_lengths
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._get_new_qc", "INFO")
     def _get_new_qc(
         cls,
         partition_ids: list,
@@ -911,6 +956,7 @@ class TextFileDispatcher(FileDispatcher):
         return new_query_compiler
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._read", "INFO")
     def _read(cls, filepath_or_buffer, **kwargs):
         """
         Read data from `filepath_or_buffer` according to `kwargs` parameters.
@@ -963,6 +1009,8 @@ class TextFileDispatcher(FileDispatcher):
         use_modin_impl = cls.check_parameters_support(
             filepath_or_buffer,
             kwargs,
+            skiprows_md,
+            header_size,
         )
         if not use_modin_impl:
             return cls.single_worker_read(
@@ -1038,6 +1086,7 @@ class TextFileDispatcher(FileDispatcher):
         return new_query_compiler
 
     @classmethod
+    @logger_decorator("PANDAS-API", "TextFileDispatcher._get_skip_mask", "INFO")
     def _get_skip_mask(cls, rows_index: pandas.Index, skiprows: Callable):
         """
         Get mask of skipped by callable `skiprows` rows.
